==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/KeepCurrent.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * KeepCurrent
 */
@JsonPropertyOrder({ KeepCurrent.JSON_PROPERTY_KEEP_CURRENT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class KeepCurrent implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_KEEP_CURRENT = "keepCurrent";
    private Boolean keepCurrent = true;

    public KeepCurrent() {
    }

    public KeepCurrent keepCurrent(Boolean keepCurrent) {

        this.keepCurrent = keepCurrent;
        return this;
    }

    /**
     * Skip deleting the user&#39;s current session when set to &#x60;true&#x60;
     *
     * @return keepCurrent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Skip deleting the user's current session when set to `true`")
    @JsonProperty(JSON_PROPERTY_KEEP_CURRENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getKeepCurrent() {
        return keepCurrent;
    }

    @JsonProperty(JSON_PROPERTY_KEEP_CURRENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKeepCurrent(Boolean keepCurrent) {
        this.keepCurrent = keepCurrent;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        KeepCurrent keepCurrent = (KeepCurrent) o;
        return Objects.equals(this.keepCurrent, keepCurrent.keepCurrent);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(keepCurrent);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class KeepCurrent {\n");
        sb.append("    keepCurrent: ").append(toIndentedString(keepCurrent)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/KeepCurrent.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * KeepCurrent
 */
@JsonPropertyOrder({ KeepCurrent.JSON_PROPERTY_KEEP_CURRENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class KeepCurrent implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_KEEP_CURRENT = "keepCurrent";
    private Boolean keepCurrent = true;

    public KeepCurrent() {
    }

    public KeepCurrent keepCurrent(Boolean keepCurrent) {

        this.keepCurrent = keepCurrent;
        return this;
    }

    /**
     * Skip deleting the user&#39;s current session when set to &#x60;true&#x60;
     *
     * @return keepCurrent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Skip deleting the user's current session when set to `true`")
    @JsonProperty(JSON_PROPERTY_KEEP_CURRENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getKeepCurrent() {
        return keepCurrent;
    }

    @JsonProperty(JSON_PROPERTY_KEEP_CURRENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKeepCurrent(Boolean keepCurrent) {
        this.keepCurrent = keepCurrent;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        KeepCurrent keepCurrent = (KeepCurrent) o;
        return Objects.equals(this.keepCurrent, keepCurrent.keepCurrent);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(keepCurrent);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class KeepCurrent {\n");
        sb.append("    keepCurrent: ").append(toIndentedString(keepCurrent)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
